@@ -1,24 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.2a2"
-#define PACKAGE_STRING "am-utils 6.2a2"
-#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
+#define PACKAGE_VERSION "6.1-rc7"
+#define PACKAGE_STRING "am-utils 6.1-rc7"
+#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
 #define HOST_CPU "sparc"
 #define HOST_VENDOR "sun"
-#define HOST_OS "solaris2.8"
+#define HOST_OS "solaris2.9"
 #define HOST_OS_NAME "solaris2"
-#define HOST_OS_VERSION "2.8"
+#define HOST_OS_VERSION "2.9"
 #define HOST_ARCH "sun4"
 #define DISTRO_NAME "none"
-#define HOST_NAME "a-solaris8.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-solaris9"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu May 11 11:28:14 EDT 2006"
+#define CONFIG_DATE "Fri Jun  3 10:10:47 EDT 2005"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.2a2"
-#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
+#define PACKAGE_VERSION "6.1-rc7"
+#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.2a2"
+#define VERSION "6.1-rc7"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -31,14 +31,13 @@
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
 #ifdef __cplusplus
-#include <stdlib.h>
+void exit (int);
 #endif
-#define HOST_HEADER_VERSION "2.8"
+#define HOST_HEADER_VERSION "2.9"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBRESOLV 1
 #define HAVE_LIBLDAP 1
-#define HAVE_LDAP_ENABLE_CACHE 1
 #define HAVE_LIBRT 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
@@ -86,14 +85,11 @@
 #define HAVE_SIGNAL 1
 #define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
-#define HAVE_STATFS 1
-#define HAVE_STATVFS 1
-#define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
+#define HAVE_STRCASECMP 1
 #define HAVE_STRCSPN 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
-#define HAVE_STRLCAT 1
 #define HAVE_STRLCPY 1
 #define HAVE_STRSPN 1
 #define HAVE_STRSTR 1
@@ -113,7 +109,6 @@
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
-#define HAVE_STRLCAT 1
 #define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
@@ -178,7 +173,6 @@
 #define HAVE_SYS_SOCKIO_H 1
 #define HAVE_SYS_STAT_H 1
 #define HAVE_SYS_STATFS_H 1
-#define HAVE_SYS_STATVFS_H 1
 #define HAVE_SYS_SYSCALL_H 1
 #define HAVE_SYS_SYSLOG_H 1
 #define HAVE_SYS_TIME_H 1
@@ -193,6 +187,8 @@
 #define HAVE_ERRNO_H 1
 #define HAVE_FCNTL_H 1
 #define HAVE_GRP_H 1
+#define HAVE_LBER_H 1
+#define HAVE_LDAP_H 1
 #define HAVE_LIBGEN_H 1
 #define HAVE_LIMITS_H 1
 #define HAVE_MALLOC_H 1
@@ -213,13 +209,9 @@
 #define HAVE_STRING_H 1
 #define HAVE_STRINGS_H 1
 #define HAVE_SYSLOG_H 1
-#define HAVE_TCPD_H 1
 #define HAVE_TIME_H 1
 #define HAVE_TIUSER_H 1
 #define HAVE_UNISTD_H 1
-#define HAVE_LBER_H 1
-#define HAVE_LDAP_H 1
-#define NEW_DBM_H "ndbm.h"
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_sunos5_8.h"
 #define HAVE_STRUCT_MNTTAB 1
@@ -245,7 +237,6 @@
 #define XDRPROC_T_TYPE xdrproc_t
 #define WORDS_BIGENDIAN 1
 #define voidp void *
-#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
 #define HAVE_EXTERN_CLNT_SPERRNO 1
@@ -261,10 +252,8 @@
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_SETITIMER 1
-#define HAVE_EXTERN_SLEEP 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
-#define HAVE_EXTERN_STRLCAT 1
 #define HAVE_EXTERN_STRLCPY 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
@@ -272,7 +261,6 @@
 #define HAVE_EXTERN_WAIT3 1
 #define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_EXTERN_XDR_CALLMSG 1
-#define HAVE_EXTERN_LDAP_ENABLE_CACHE 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
 #define HAVE_TRANSPORT_TYPE_TLI 1
@@ -284,17 +272,12 @@
 #define HAVE_UFS_ARGS_T_FLAGS 1
 #define HAVE_STRUCT_FHSTATUS_FHS_FH 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
-#define HAVE_NFS_ARGS_T_ACDIRMAX 1
 #define HAVE_NFS_ARGS_T_ACREGMIN 1
-#define HAVE_NFS_ARGS_T_ACREGMAX 1
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_AUTOFS_ARGS_T_ADDR 1
 #define HAVE_MAP_FILE 1
-#define HAVE_MAP_SUN 1
 #define HAVE_MAP_EXEC 1
 #define HAVE_MAP_LDAP 1
-#define HAVE_DBM_OPEN 1
-#define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_NISPLUS 1
 #define HAVE_MAP_PASSWD 1
@@ -366,7 +349,6 @@
 #define MNTTAB_OPT_VERS "vers"
 #define MNTTAB_OPT_WSIZE "wsize"
 #define MNT2_GEN_OPT_DATA 0x4
-#define MNT2_GEN_OPT_FORCE 0x400
 #define MNT2_GEN_OPT_FSS 0x2
 #define MNT2_GEN_OPT_NOMNTTAB 0x800
 #define MNT2_GEN_OPT_NOSUID 0x10
